@@ -41,5 +41,4 @@
 #' lnd_cycle_p_mini = dplyr::select(lnd_cycle_p, osm_id, name, capacity, cyclestreets_id, description)
 #' nrow(lnd_cycle_p_mini)
 #' }
-
-NULL
\ No newline at end of file
+"cycle_hire_osm"
\ No newline at end of file
