@@ -23,5 +23,4 @@
 #' 
 #' summary(us_states_df)
 #' 
-
-NULL
+"us_states_df"
\ No newline at end of file
